@@ -11,12 +11,13 @@ except ImportError:
     # NOTE - could use subprocess to get from git?
     __rev__ = "local"
 
-__version__ = "0.10.2"
+__version__ = "0.10.5"
 
-TEST_ENV = bool(os.environ.get("DP_TEST_ENV", ""))
+_TEST_ENV = bool(os.environ.get("DP_TEST_ENV", ""))
+_IN_PYTEST = "pytest" in sys.modules
 
 # Other useful re-exports
-from .common.utils import log, _setup_dp_logging
+from .common.utils import enable_logging, log, _setup_dp_logging
 
 # Public API re-exports
 from .client.api import (
