@@ -26,7 +26,7 @@ from packaging.version import Version
 from requests import HTTPError, Response  # noqa: F401
 from requests_toolbelt import MultipartEncoder, MultipartEncoderMonitor
 
-from datapane import TEST_ENV, __version__
+from datapane import _TEST_ENV, __version__
 from datapane.client import config as c
 from datapane.client.utils import (
     IncompatibleVersionError,
@@ -92,8 +92,8 @@ class DPTmpFile:
     def mime(self) -> MIME:
         return guess_type(self.file)
 
-    def __str__(self):
-        return str(self.file)
+    def __str__(self) -> str:
+        return self.name
 
 
 @atexit.register
@@ -119,7 +119,7 @@ def check_pip_version() -> None:
     if pip_version > cli_version:
         error_msg = (
             f"Your client is out-of-date (version {cli_version}) and may be causing errors, "
-            + f"please upgrade to version {pip_version}"
+            + f"please upgrade to version {pip_version} - see https://docs.datapane.com/tut-getting-started#upgrading"
         )
     else:  # no newer pip - perhaps local dev?
         error_msg = f"Your client is out-of-date (version {cli_version}) with the server and may be causing errors"
@@ -158,7 +158,7 @@ class Resource:
     # keep session as classvar to share across all DP accesses - however will be
     # tied to current instance config
     session = requests.Session()
-    timeout = None if TEST_ENV else (6.10, 54)
+    timeout = None if _TEST_ENV else (6.10, 54)
 
     def __init__(self, endpoint: str):
         self.endpoint = endpoint.split("/api", maxsplit=1)[-1]
@@ -169,16 +169,16 @@ class Resource:
         self.session.headers.update(Authorization=f"Token {config.token}", Datapane_API_Version=__version__)
 
     def _check_endpoint(self, url: str):
-        # raise exception if unavailable object is being accessed on the public datapane
-        public_endpoints = ["files", "oembed", "reports", "settings", "users"]
+        # raise exception if unavailable object is being accessed on the basic instance
+        basic_endpoints = ["files", "oembed", "reports", "settings", "users"]
         url = furl(url)
         url_parts = url.path.segments
         if (
             url.host in ["datapane.com"]  # , "localhost"] - we want to access OrgSolo locally
             and url_parts[0] == "api"
-            and url_parts[1] not in public_endpoints
+            and url_parts[1] not in basic_endpoints
         ):
-            raise UnsupportedResourceError(f"{url_parts[1].title()} are part of Datapane for Teams.")
+            raise UnsupportedResourceError(f"{url_parts[1].title()} are part of Datapane Enterprise.")
 
     def post(self, params: t.Dict = None, **data: JSON) -> JSON:
         params = params or dict()
@@ -269,6 +269,7 @@ def do_download_file(download_url: t.Union[str, furl], fn: t.Optional[NPath] = N
         download_url.origin = c.config.server
 
     with requests.get(str(download_url.url), stream=True) as r:
+        r.raise_for_status()
         x = r.headers.get("Content-Disposition")
         if not fn:
             if x and "filename" in x:
