@@ -652,6 +652,9 @@ class Table(AssetBlock):
     """
     Table blocks store the contents of a dataframe as a HTML `table` whose style can be customised using
     pandas' `Styler` API.
+
+    ..note:: Please use Table component when saving files locally over the DataTable component which has more features but requires publishing your report
+
     """
 
     _tag = "Table"
@@ -676,7 +679,7 @@ class DataTable(AssetBlock):
     and can be downloaded by them as a CSV or Excel file.
 
     ..tip:: For smaller dataframes where you don't require sorting and filtering, also consider using the `Table` block
-    ..note:: The DataTable component requires a server and is not supported when saving locally, please publish such reports to a Datapane Server or use dp.Table
+    ..note:: The DataTable component has advanced analysis features that requires a server and is not supported when saving locally, please publish such reports to a Datapane Server or use dp.Table
 
     """
 
