@@ -21,10 +21,11 @@ from jinja2 import Environment, FileSystemLoader, Markup, Template, contextfunct
 from lxml import etree
 from lxml.etree import Element
 
+from datapane.client import config as c
 from datapane.client.api.common import DPTmpFile, Resource
 from datapane.client.api.dp_object import DPObjectRef
 from datapane.client.api.runtime import _report
-from datapane.client.utils import DPError, UnsupportedFeature
+from datapane.client.utils import DPError, UnsupportedFeatureError
 from datapane.common import log, timestamp
 from datapane.common.report import local_report_def, validate_report_doc
 
@@ -67,6 +68,16 @@ def is_jupyter() -> bool:
         return False
 
 
+def display_msg(text: str, md: str = None):
+    if is_jupyter():
+        from IPython.display import Markdown, display
+
+        msg = md or text
+        display(Markdown(msg))
+    else:
+        print(text)
+
+
 @contextfunction
 def include_raw(ctx, name):
     """ Normal jinja2 {% include %} doesn't escape {{...}} which appear in React's source code """
@@ -110,18 +121,10 @@ class ReportFileWriter:
         else:
             SKIP_DISPLAY_MSG = True
 
-        if is_jupyter():
-            from IPython.display import Markdown, display
-
-            display(
-                Markdown(
-                    "Thanks for using **Datapane**, to automate and securely share reports in your organization please visit [Datapane Enterprise](https://datapane.com/enterprise/)"
-                )
-            )
-        else:
-            print(
-                "Thanks for using Datapane, to automate and securely share reports in your organization please visit Datapane Enterprise - https://datapane.com/enterprise/"
-            )
+        display_msg(
+            text="Thanks for using Datapane, to automate and securely share reports in your organization please see Datapane Cloud - https://datapane.com/enterprise/",
+            md="Thanks for using **Datapane**, to automate and securely share reports in your organization please see [Datapane Cloud](https://datapane.com/enterprise/)",
+        )
 
     def write(self, report_doc: str, path: str, report_type: ReportType, name: str, author: t.Optional[str]):
 
@@ -197,9 +200,7 @@ class Report(DPObjectRef):
             # add additional top-level Group element to group mixed elements
             self.pages = [Page(blocks=[Group(blocks=pages)])]
 
-    def _gen_report(
-        self, embedded: bool, title: str, description: str = "Description", author: str = "Anonymous"
-    ) -> t.Tuple[str, t.List[Path]]:
+    def _gen_report(self, embedded: bool, title: str, description: str = "Description") -> t.Tuple[str, t.List[Path]]:
         """Build XML report document"""
         # convert Pages to XML
         s = BuilderState(embedded)
@@ -208,7 +209,7 @@ class Report(DPObjectRef):
         # add main structure and Meta
         report_doc: Element = E.Report(
             E.Meta(
-                E.Author(author),  # TODO - get username from config?
+                E.Author(c.config.username or "anonymous"),
                 E.CreatedOn(timestamp()),
                 E.Title(title),
                 E.Description(description),
@@ -227,14 +228,15 @@ class Report(DPObjectRef):
         if embedded:
             uses_datatable: bool = processed_report_doc.xpath("boolean(/Report/Main//DataTable)")
             if uses_datatable:
-                raise UnsupportedFeature(
-                    "DataTable component not supported when saving locally, please publish to a Datapane Server or use dp.Table"
+                raise UnsupportedFeatureError(
+                    "DataTable component contains advanced analysis features that are not supported when saving or previewing locally,"
+                    + " please either publish your report to a Datapane Server or use the dp.Table component instead"
                 )
 
         # convert to string
         report_str = etree.tounicode(processed_report_doc, pretty_print=True)
-        log.debug("Built Report")
-        log.debug(report_str)
+        log.debug("Successfully Built Report")
+        # log.debug(report_str)
         return (report_str, _s.attachments)
 
     def publish(
@@ -255,12 +257,12 @@ class Report(DPObjectRef):
             name: The report name - can include spaces, caps, symbols, etc., e.g. "Profit & Loss 2020"
             description: A high-level description for the report, this is displayed in searches and thumbnails
             source_url: A URL pointing to the source code for the report, e.g. a GitHub repo or a Colab notebook
-            visibility: one of `"PUBLIC"` _(default on Public)_, or `"PRIVATE"` _(limited on Public, unlimited on Teams)_
+            visibility: one of `"PUBLIC"` _(default on Datapane.com)_, or `"PRIVATE"` _(limited on Datapame.com, unlimited on Datapane Enterprise)_
             open: Open the file in your browser after creating
             tags: A list of tags (as strings) used to categorise your report
         """
 
-        print("Publishing report and associated data - please wait..")
+        display_msg("Publishing report and associated data - please wait..")
 
         # process params
         tags = tags or []
@@ -285,7 +287,8 @@ class Report(DPObjectRef):
         _report.append(self)
         if open:
             webbrowser.open_new_tab(self.web_url)
-        print(f"Report successfully published at {self.web_url}")
+
+        display_msg(text=f"Report successfully published at {self.web_url}")
 
     def save(self, path: str, open: bool = False, name: t.Optional[str] = None, author: t.Optional[str] = None) -> None:
         """Save the report to a local HTML file
@@ -301,9 +304,8 @@ class Report(DPObjectRef):
         if not name:
             name = Path(path).stem
 
-        local_doc, _ = self._gen_report(embedded=True, title=name, author=author or "Anonymous")
-
-        self._local_writer.write(local_doc, path, self.report_type, name=name, author=author)
+        local_doc, _ = self._gen_report(embedded=True, title=name)
+        self._local_writer.write(local_doc, path, self.report_type, name=name, author=author or c.config.username)
 
         if open:
             path_uri = f"file://{osp.realpath(osp.expanduser(path))}"
@@ -314,8 +316,8 @@ class Report(DPObjectRef):
         Preview the report inside your currently running Jupyter notebook
 
         Args:
-            width: Width of the report preview in Jupyter (default: 600)
-            height: Height of the report preview in Jupyter (default: 500)
+            width: Width of the report preview in Jupyter (default: 960)
+            height: Height of the report preview in Jupyter (default: 700)
         """
         if is_jupyter():
             from IPython.display import IFrame
