@@ -10,7 +10,7 @@ from datapane.common import JDict
 
 
 def add_help_text(x: str) -> str:
-    return f"{x}\nPlease visit www.github.com/datapane/datapane to raise issue / discuss if error repeats"
+    return f"{x}\nPlease run with `dp.enable_logging()`, or visit https://www.github.com/datapane/datapane to raise issue / discuss if error repeats"
 
 
 class DPError(Exception):
@@ -39,10 +39,18 @@ class InvalidTokenError(DPError):
     ...
 
 
-class UnsupportedFeature(DPError):
+class UnsupportedFeatureError(DPError):
     ...
 
 
+class MissingCloudPackagesError(DPError):
+    def __init__(self, *a, **kw):
+        # quick hack until we setup a conda meta-package for cloud
+        self.args = (
+            "Cloud packages not found, please run `pip install datapane[cloud]` or `conda install -c conda-forge nbconvert flit-core`",
+        )
+
+
 def success_msg(msg: str):
     click.secho(msg, fg="green")
 
